Lirc

Struct Lirc 

pub struct Lirc { /* private fields */ }
A physical or virtual lirc device

Implementations

Source

impl Lirc

pub fn open<P: AsRef<Path>>(path: P) -> Result<Lirc>

Open a lirc chardev, which should have a path like “/dev/lirc0”

pub fn send(&mut self, data: &[u32]) -> Result<()>

Transmit infrared. Each element in the array describes the number of microseconds the IR should be on and off, respectively.

pub fn can_send(&self) -> bool

Does this lirc device support sending

pub fn can_set_send_carrier(&self) -> bool

Does this lirc device support setting send carrier

pub fn can_set_send_duty_cycle(&self) -> bool

Does this lirc device support setting send duty cycle

pub fn can_set_send_transmitter_mask(&self) -> bool

Does this lirc device support setting transmitter mask

pub fn set_send_carrier(&mut self, carrier: u32) -> Result<()>

Set the send carrier. A carrier of 0 means unmodulated

pub fn set_send_duty_cycle(&mut self, duty_cycle: u32) -> Result<()>

Set the send carrier. A carrier of 0 means unmodulated

pub fn num_transmitters(&mut self) -> Result<u32>

pub fn set_transmitter_mask(&mut self, transmitter_mask: u32) -> Result<()>

Set the send carrier. A carrier of 0 means unmodulated

pub fn can_set_timeout(&self) -> bool

Does this lirc device support setting send carrier

pub fn set_timeout(&mut self, timeout: u32) -> Result<()>

Set the receiving timeout in microseconds

pub fn get_timeout(&self) -> Result<u32>

Get the current receiving timeout in microseconds

pub fn get_min_max_timeout(&self) -> Result<Range<u32>>

Get the minimum and maximum timeout this lirc device supports

pub fn can_use_wideband_receiver(&self) -> bool

Does this lirc device support setting send carrier

pub fn set_wideband_receiver(&mut self, enable: bool) -> Result<()>

Set the receiving timeout in microseconds

pub fn can_measure_carrier(&self) -> bool

Does this lirc device support measuring the carrier

pub fn set_measure_carrier(&mut self, enable: bool) -> Result<()>

Enabling measuring the carrier

pub fn can_receive_raw(&self) -> bool

Does this lirc device support receiving in raw format

pub fn receive_raw(&mut self, result: &mut Vec<LircRaw>) -> Result<()>

Read the raw IR. If there is nothing to be read, the result vector will be set to length 0. Otherwise, up to the capacity of result entries will be read.

pub fn can_receive_scancodes(&self) -> bool

Does this lirc device support receiving in decoded scancode format

pub fn scancode_mode(&mut self) -> Result<()>

Switch to scancode mode

pub fn receive_scancodes( &mut self, result: &mut Vec<LircScancode>, ) -> Result<()>

Read the decoded IR.

pub fn can_get_rec_resolution(&self) -> bool

Can we get the receiver resolution

pub fn receiver_resolution(&self) -> Result<u32>

Enabling measuring the carrier

pub fn attach_bpf(&self, bpf: &[u8]) -> Result<(), String>

Load and attach bpf program. The bpf program should a valid ELF object file, which contains a single LircMode2 program.

pub fn query_bpf(&self) -> Result<Option<Vec<String>>, ProgramError>

Query bpf programs attached to lirc dev. Returns Ok(None) if there is no support for bpf programs with the current kernel.

pub fn clear_bpf(&self) -> Result<(), ProgramError>

Remove all attached bpf programs