pub struct Lirc { /* private fields */ }Expand description
A physical or virtual lirc device
Implementations
Sourceimpl Lirc
impl Lirc
Sourcepub fn open<P: AsRef<Path>>(path: P) -> Result<Lirc>
pub fn open<P: AsRef<Path>>(path: P) -> Result<Lirc>
Open a lirc chardev, which should have a path like “/dev/lirc0”
Sourcepub fn send(&mut self, data: &[u32]) -> Result<()>
pub fn send(&mut self, data: &[u32]) -> Result<()>
Transmit infrared. Each element in the array describes the number of microseconds the IR should be on and off, respectively.
Sourcepub fn can_set_send_carrier(&self) -> bool
pub fn can_set_send_carrier(&self) -> bool
Does this lirc device support setting send carrier
Sourcepub fn can_set_send_duty_cycle(&self) -> bool
pub fn can_set_send_duty_cycle(&self) -> bool
Does this lirc device support setting send duty cycle
Sourcepub fn can_set_send_transmitter_mask(&self) -> bool
pub fn can_set_send_transmitter_mask(&self) -> bool
Does this lirc device support setting transmitter mask
Sourcepub fn set_send_carrier(&mut self, carrier: u32) -> Result<()>
pub fn set_send_carrier(&mut self, carrier: u32) -> Result<()>
Set the send carrier. A carrier of 0 means unmodulated
Sourcepub fn set_send_duty_cycle(&mut self, duty_cycle: u32) -> Result<()>
pub fn set_send_duty_cycle(&mut self, duty_cycle: u32) -> Result<()>
Set the send carrier. A carrier of 0 means unmodulated
pub fn num_transmitters(&mut self) -> Result<u32>
Sourcepub fn set_transmitter_mask(&mut self, transmitter_mask: u32) -> Result<()>
pub fn set_transmitter_mask(&mut self, transmitter_mask: u32) -> Result<()>
Set the send carrier. A carrier of 0 means unmodulated
Sourcepub fn can_set_timeout(&self) -> bool
pub fn can_set_timeout(&self) -> bool
Does this lirc device support setting send carrier
Sourcepub fn set_timeout(&mut self, timeout: u32) -> Result<()>
pub fn set_timeout(&mut self, timeout: u32) -> Result<()>
Set the receiving timeout in microseconds
Sourcepub fn get_timeout(&self) -> Result<u32>
pub fn get_timeout(&self) -> Result<u32>
Get the current receiving timeout in microseconds
Sourcepub fn get_min_max_timeout(&self) -> Result<Range<u32>>
pub fn get_min_max_timeout(&self) -> Result<Range<u32>>
Get the minimum and maximum timeout this lirc device supports
Sourcepub fn can_use_wideband_receiver(&self) -> bool
pub fn can_use_wideband_receiver(&self) -> bool
Does this lirc device support setting send carrier
Sourcepub fn set_wideband_receiver(&mut self, enable: bool) -> Result<()>
pub fn set_wideband_receiver(&mut self, enable: bool) -> Result<()>
Set the receiving timeout in microseconds
Sourcepub fn can_measure_carrier(&self) -> bool
pub fn can_measure_carrier(&self) -> bool
Does this lirc device support measuring the carrier
Sourcepub fn set_measure_carrier(&mut self, enable: bool) -> Result<()>
pub fn set_measure_carrier(&mut self, enable: bool) -> Result<()>
Enabling measuring the carrier
Sourcepub fn can_receive_raw(&self) -> bool
pub fn can_receive_raw(&self) -> bool
Does this lirc device support receiving in raw format
Sourcepub fn receive_raw(&mut self, result: &mut Vec<LircRaw>) -> Result<()>
pub fn receive_raw(&mut self, result: &mut Vec<LircRaw>) -> Result<()>
Read the raw IR. If there is nothing to be read, the result vector will be set to length 0. Otherwise, up to the capacity of result entries will be read.
Sourcepub fn can_receive_scancodes(&self) -> bool
pub fn can_receive_scancodes(&self) -> bool
Does this lirc device support receiving in decoded scancode format
Sourcepub fn scancode_mode(&mut self) -> Result<()>
pub fn scancode_mode(&mut self) -> Result<()>
Switch to scancode mode
Sourcepub fn receive_scancodes(
&mut self,
result: &mut Vec<LircScancode>,
) -> Result<()>
pub fn receive_scancodes( &mut self, result: &mut Vec<LircScancode>, ) -> Result<()>
Read the decoded IR.
Sourcepub fn can_get_rec_resolution(&self) -> bool
pub fn can_get_rec_resolution(&self) -> bool
Can we get the receiver resolution
Sourcepub fn receiver_resolution(&self) -> Result<u32>
pub fn receiver_resolution(&self) -> Result<u32>
Enabling measuring the carrier
Sourcepub fn attach_bpf(&self, bpf: &[u8]) -> Result<(), String>
pub fn attach_bpf(&self, bpf: &[u8]) -> Result<(), String>
Load and attach bpf program. The bpf program should a valid ELF object file, which contains a single LircMode2 program.
Sourcepub fn query_bpf(&self) -> Result<Option<Vec<String>>, ProgramError>
pub fn query_bpf(&self) -> Result<Option<Vec<String>>, ProgramError>
Query bpf programs attached to lirc dev. Returns Ok(None) if there is no support for bpf programs with the current kernel.
Sourcepub fn clear_bpf(&self) -> Result<(), ProgramError>
pub fn clear_bpf(&self) -> Result<(), ProgramError>
Remove all attached bpf programs