pub fn encode(
lirc_remotes: &[Remote],
remote: Option<&str>,
code_name: &str,
repeats: u64,
) -> Result<Message, String>Expand description
Encode the given codes into raw IR, ready for transmit. This has been validated against the send output of lircd using all the remotes present in the lirc-remotes database.